==> conditional_parent_widget-0.0.1.tar.gz: example/lib/main.dart <==
import 'package:conditional_parent_widget/conditional_parent_widget.dart';
import 'package:flutter/material.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData.dark(),
      home: MyHomePage(title: 'ConditionalParentWidget Example'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  MyHomePage({Key? key, required this.title}) : super(key: key);

  final String title;

  @override
  _MyHomePageState createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  int _counter = 0;

  final boxDecoration = BoxDecoration(
    border: Border.all(
      color: Colors.blueAccent,
    ),
    borderRadius: BorderRadius.all(Radius.circular(5)),
  );

  void _incrementCounter() {
    setState(() {
      _counter++;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget.title),
      ),
      body: Center(
        // Conditional Parent without breaking the tree
        child: ConditionalParentWidget(
          // Build parent around child if counter is divisible by 10
          condition: _counter % 10 == 0,
          // Build parent iff condition is true
          parentBuilder: (child) {
            return Container(
              padding: EdgeInsets.all(10),
              decoration: boxDecoration,
              child: child,
            );
          },
          // Always build child
          child: Column(
            mainAxisSize: MainAxisSize.min,
            mainAxisAlignment: MainAxisAlignment.center,
            children: <Widget>[
              Text(
                'You have pushed the button this many times:',
              ),
              Text(
                '$_counter',
                style: Theme.of(context).textTheme.headline4,
              ),
            ],
          ),
        ),
      ),
      floatingActionButton: FloatingActionButton(
        onPressed: _incrementCounter,
        tooltip: 'Increment',
        child: Icon(Icons.add),
      ), // This trailing comma makes auto-formatting nicer for build methods.
    );
  }
}

==> conditional_parent_widget-0.0.2.tar.gz: example/lib/main.dart <==
import 'package:conditional_parent_widget/conditional_parent_widget.dart';
import 'package:flutter/material.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData.dark(),
      home: MyHomePage(title: 'ConditionalParentWidget Example'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  MyHomePage({Key? key, required this.title}) : super(key: key);

  final String title;

  @override
  _MyHomePageState createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  int _counter = 0;

  final boxDecoration = BoxDecoration(
    border: Border.all(
      color: Colors.blueAccent,
    ),
    borderRadius: BorderRadius.all(Radius.circular(5)),
  );

  void _incrementCounter() {
    setState(() {
      _counter++;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget.title),
      ),
      body: Center(
        // Conditional Parent without breaking the tree
        child: ConditionalParentWidget(
          // Build parent around child if counter is divisible by 10
          condition: _counter % 10 == 0,
          // Build parent iff condition is true
          parentBuilder: (child) {
            return Container(
              padding: EdgeInsets.all(10),
              decoration: boxDecoration,
              child: child,
            );
          },
          // Always build child
          child: Column(
            mainAxisSize: MainAxisSize.min,
            mainAxisAlignment: MainAxisAlignment.center,
            children: <Widget>[
              Text(
                'You have pushed the button this many times:',
              ),
              Text(
                '$_counter',
                style: Theme.of(context).textTheme.headlineMedium,
              ),
            ],
          ),
        ),
      ),
      floatingActionButton: FloatingActionButton(
        onPressed: _incrementCounter,
        tooltip: 'Increment',
        child: Icon(Icons.add),
      ),
    );
  }
}
